@@ -41,6 +41,8 @@ static const char *ipsec_keys[] = {NM_L2TP_KEY_IPSEC_ENABLE,
                                    NM_L2TP_KEY_IPSEC_IPCOMP,
                                    NM_L2TP_KEY_IPSEC_IKEV2,
                                    NM_L2TP_KEY_IPSEC_PFS,
+                                   NM_L2TP_KEY_IPSEC_PSK "-flags",
+                                   NM_L2TP_KEY_MACHINE_CERTPASS "-flags",
                                    NULL};
 
 static void
@@ -178,8 +180,6 @@ tls_cert_changed_cb(GtkWidget *chooser, gpointer user_data)
      * connection (CA cert, cert, private key).
      **/
 
-    crypto_init_openssl();
-
     fname = nma_cert_chooser_get_cert(this, NULL);
     if (fname)
         dirname = g_path_get_dirname(fname);
@@ -239,7 +239,6 @@ tls_cert_changed_cb(GtkWidget *chooser, gpointer user_data)
     g_free(ca_cert_fname);
     g_free(cert_fname);
     g_free(key_fname);
-    crypto_deinit_openssl();
 }
 
 static void
@@ -789,6 +788,12 @@ ipsec_dialog_new_hash_from_dialog(GtkWidget *dialog, GError **error)
     if (value && *value) {
         g_hash_table_insert(hash, g_strdup(NM_L2TP_KEY_IPSEC_PSK), g_strdup(value));
     }
+    pw_flags = nma_utils_menu_to_secret_flags(widget);
+    if (pw_flags != NM_SETTING_SECRET_FLAG_NONE) {
+        g_hash_table_insert(hash,
+                            g_strdup(NM_L2TP_KEY_IPSEC_PSK "-flags"),
+                            g_strdup_printf("%d", pw_flags));
+    }
 
     widget = GTK_WIDGET(gtk_builder_get_object(builder, "machine_ca_chooser"));
     value  = nma_cert_chooser_get_cert(NMA_CERT_CHOOSER(widget), NULL);
