@@ -111,11 +111,25 @@ _call_editor_factory(gpointer           factory,
 static NMVpnEditor *
 get_editor(NMVpnEditorPlugin *iface, NMConnection *connection, GError **error)
 {
+    gpointer    gtk3_only_symbol;
+    GModule *   self_module;
+    const char *editor;
+
     g_return_val_if_fail(L2TP_IS_PLUGIN_UI(iface), NULL);
     g_return_val_if_fail(NM_IS_CONNECTION(connection), NULL);
     g_return_val_if_fail(!error || !*error, NULL);
 
-    return nm_vpn_plugin_utils_load_editor(NM_PLUGIN_DIR "/libnm-vpn-plugin-l2tp-editor.so",
+    self_module = g_module_open(NULL, 0);
+    g_module_symbol(self_module, "gtk_container_add", &gtk3_only_symbol);
+    g_module_close(self_module);
+
+    if (gtk3_only_symbol) {
+            editor = "libnm-vpn-plugin-l2tp-editor.so";
+    } else {
+            editor = "libnm-gtk4-vpn-plugin-l2tp-editor.so";
+    }
+
+    return nm_vpn_plugin_utils_load_editor(editor,
                                            "nm_vpn_editor_factory_l2tp",
                                            _call_editor_factory,
                                            iface,
